@@ -20,7 +20,7 @@
 #  respective owners and no grant or license is provided thereof.
 
 package PDL::Opt::Simplex::Simple;
-$VERSION = '1.5';
+$VERSION = '1.6';
 
 use 5.010;
 use strict;
@@ -136,6 +136,19 @@ sub _optimize
 	delete $self->{prev_minima};
 	delete $self->{prev_minima_count};
 
+	# Make an initial call if this is the first pass to create a basis for
+	# {best_vars} in case the starting point is better than all other
+	# simplex attempts.  The result will be cached so if Simplex calls with
+	# the same value then it will not waste an iteration (unless nocache is
+	# flagged).
+	#
+	# Also call the log function in case it is useful:
+	if ($self->{optimization_pass} == 1)
+	{
+		my $vec_result = $self->_simplex_f($vec_initial);
+		$self->_simplex_log($vec_initial, $vec_result, pdl $self->{ssize});
+	}
+
 	my ( $vec_optimal, $opt_ssize, $optval );
 
 	# Catch early cancellation
@@ -324,7 +337,8 @@ sub _simplex_log
 
 	my @log_vars = $self->_get_simplex_vars($vec);
 	$self->{log}->($log_vars[0], {
-		ssize => $ssize->sclr,
+		ssize =>
+			ref($ssize) eq 'PDL' ? $ssize->sclr : $ssize,
 		minima => $minima,
 		elapsed => $elapsed,
 		srand => $self->{srand},
@@ -332,7 +346,8 @@ sub _simplex_log
 
 		num_passes => scalar( @{ $self->{_ssize} }),
 		best_pass => $self->{best_pass},
-		best_minima => $self->{best_minima}->sclr,
+		best_minima =>
+			ref($self->{best_minima}) eq 'PDL' ? $self->{best_minima}->sclr : $self->{best_minima},
 		best_vars => $self->{best_vars},
 		log_count => $self->{log_count},
 		cancel => $self->{cancel},
